@@ -105,10 +105,9 @@ def invalidate_cachekey_volatile_for(name, get_again=False, invalidate_cache=Tru
     volatiles = getattr(portal, VOLATILE_ATTR, {})
     if volatile_name in volatiles:
         del volatiles[volatile_name]
-    # when the key is invalidated, get_cachekey_volatile so it
-    # stores a new date and it avoids a second write
-    if get_again:
-        get_cachekey_volatile(volatile_name)
+    # if get_again=True, when the key is invalidated,
+    # get_cachekey_volatile so it stores a new date and it avoids a second write
+    date = get_cachekey_volatile(volatile_name) if get_again else None
     # when date is invalidated, every cache using it is stale
     # so we may either specifically invalidate this cached methods
     # or just wait for ram.cache to do it's cleanup itself
@@ -118,6 +117,7 @@ def invalidate_cachekey_volatile_for(name, get_again=False, invalidate_cache=Tru
             for method in mapping[name]:
                 cleanRamCacheFor(method)
             mapping.pop(name)
+    return date
 
 
 def _generate_params_key(*args, **kwargs):
@@ -226,7 +226,9 @@ def get_plone_groups_for_user_cachekey(method, user_id=None, user=None, the_obje
 
 @ram.cache(get_plone_groups_for_user_cachekey)
 def get_plone_groups_for_user(user_id=None, user=None, the_objects=False):
-    """Just return user.getGroups but cached."""
+    """Just return user.getGroups but cached.
+       This method is tested in
+       Products.PloneMeeting.tests.testToolPloneMeeting.test_pm_Get_plone_groups_for_user."""
     if api.user.is_anonymous():
         return []
     if user is None:
