@@ -4,6 +4,7 @@ from imio.helpers.xhtml import addClassToContent
 from imio.helpers.xhtml import addClassToLastChildren
 from imio.helpers.xhtml import imagesToData
 from imio.helpers.xhtml import imagesToPath
+from imio.helpers.xhtml import is_html
 from imio.helpers.xhtml import markEmptyTags
 from imio.helpers.xhtml import object_link
 from imio.helpers.xhtml import removeBlanks
@@ -19,8 +20,8 @@ from Products.ATContentTypes.interfaces import IImageContent
 import urllib
 
 
-picsum_image1_url = 'https://i.picsum.photos/id/10/200/300.jpg?hmac=94QiqvBcKJMHpneU69KYg2pky8aZ6iBzKrAuhSUBB9s'
-picsum_image2_url = 'https://i.picsum.photos/id/1082/200/200.jpg?hmac=3usO1ziO7kCseIG52ruhRigxyk39W_L9eECWe1Hs6fY'
+picsum_image1_url = 'https://fastly.picsum.photos/id/10/200/300.jpg?hmac=94QiqvBcKJMHpneU69KYg2pky8aZ6iBzKrAuhSUBB9s'
+picsum_image2_url = 'https://fastly.picsum.photos/id/1082/200/200.jpg?hmac=3usO1ziO7kCseIG52ruhRigxyk39W_L9eECWe1Hs6fY'
 
 base64_img_data = "data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABQAAAAUCAYAAACNiR0NAAADWElEQVQ4ja2VX2yTBRTFj2QP" \
     "JGtoLWWMZWN/tDBW1oQSoatuUNycNnWYMV1M9nVrJgRit6msVWuBj5fhQkhB5jagIqDQP2MmkKyDbToSKjSAo2yYInUhuiFEohghcQH7HR9M" \
@@ -911,3 +912,11 @@ class TestXHTMLModule(IntegrationTestCase):
             css_class="to-hide",
             new_content=u"replaced")
         self.assertEqual(res, expected_text_with_sub)
+
+    def test_is_html(self):
+        """ """
+        self.assertFalse(is_html(None))
+        self.assertFalse(is_html(""))
+        self.assertFalse(is_html("None"))
+        self.assertTrue(is_html("<p>My text</p>"))
+        self.assertTrue(is_html("<p>My text <span>text 2</span>.</p>"))
